@@ -17,34 +17,6 @@ videotrack = None
 
 class GSPeerConnectionBroadcaster:
 
-    def create_local_tracks(self, device, transcode=True):
-        global relay, webcam
-        if relay is None:
-            if platform.system() == "Darwin":
-                options = {
-                    "video_size": f"{str(self.gsdbs.credentials['hres'])}x{str(self.gsdbs.credentials['vres'])}",
-                    "preset": "veryfast",
-                    "framerate": str(self.gsdbs.credentials["framerate"]),
-                    "c:v": "h264_v4l2m2m",
-                    "input_format": "h264",
-                    "pixelformat": "H264"
-                }
-                webcam = MediaPlayer("default:none", format="avfoundation", options=options)
-            elif platform.system() == "Windows":
-                webcam = MediaPlayer(f"video={device}", format="dshow")
-            else:
-                options = {
-                    "video_size": f"{str(self.gsdbs.credentials['hres'])}x{str(self.gsdbs.credentials['vres'])}",
-                    "preset": "veryfast",
-                    "framerate": str(self.gsdbs.credentials["framerate"]),
-                    "c:v": "h264_v4l2m2m",
-                    "input_format": "h264",
-                    "pixelformat": "H264"
-                }
-                webcam = MediaPlayer(device, format="v4l2", options=options)
-            relay = MediaRelay()
-        return relay.subscribe(webcam.video, buffered=False)
-
     def create_local_tracks_new(self, play_from, decode):
         global relay, webcam
 
@@ -101,15 +73,9 @@ class GSPeerConnectionBroadcaster:
             self.peerConnections[id] = pc
 
             audio, video = self.create_local_tracks_new(
-                None, decode=True
+                None, decode=self.gsdbs.credentials["decode"]
             )
-            channel = pc.createDataChannel("message")
-
-            # def send_data():
-            #     channel.send("test123")
-            # channel.on("open", send_data)
-
-            video_codec = "video/H264"
+            video_codec = self.gsdbs.credentials["videocodec"]
 
             if audio:
                 pc.addTrack(audio)
